@@ -4,6 +4,7 @@ import pandas as pd
 import numpy as np
 import logging
 from pandas.io.json import json_normalize
+import re
 global logger
 logger = logging.getLogger()
 import json
@@ -19,6 +20,11 @@ def get(service_uri,query,auth=None):
 
 
 class Facets:
+    def __init__(self):
+        self.set_annotation_folder()
+
+    def set_annotation_folder(self,annotation_folder='./annotation/'):
+        self.annotation_folder = annotation_folder;
 
     def getQuery(self,query='*:*',facets=["endpointcategory_s","effectendpoint_s","unit_s"],fq='', rows=0):
         json_facet = self.getNestedFacets(facets);
@@ -120,20 +126,20 @@ class Facets:
             this.parse(response_json['facets'],prefix=">",process=process)
             df = pd.DataFrame(_stats,columns=colnames).drop("Z", axis=1)
             if "substanceType_s" in df.columns:
-                a = annotation.DictionarySubstancetypes(verbose=False)
+                a = annotation.DictionarySubstancetypes(folder=this.annotation_folder,verbose=False)
                 df[ 'substanceType_name']=df[ 'substanceType_s'].apply(a.annotate)
             if "substanceType_hs" in df.columns:
-                a = annotation.DictionarySubstancetypes(verbose=False)
+                a = annotation.DictionarySubstancetypes(folder=this.annotation_folder,verbose=False)
                 a.verbose=False
                 df[ 'substanceType_name']=df[ 'substanceType_hs'].apply(a.annotate)
             if "endpointcategory_s" in df.columns:
-                a = annotation.DictionaryEndpointCategory()
+                a = annotation.DictionaryEndpointCategory(folder=this.annotation_folder)
                 df[ 'endpointcategory_term']=df[ 'endpointcategory_s'].apply(a.annotate)
-                a = annotation.DictionaryEndpointCategoryNames()
+                a = annotation.DictionaryEndpointCategoryNames(folder=this.annotation_folder)
                 df[ 'endpointcategory_name']=df[ 'endpointcategory_s'].apply(a.annotate)
 
             if "method_term" in df.columns:
-                a = annotation.DictionaryAssays()
+                a = annotation.DictionaryAssays(folder=this.annotation_folder)
                 df[ 'method_term']=df[method_field].apply(a.annotate)
             return (df)
         else:
@@ -388,7 +394,8 @@ class StudyDocuments:
                     try:
                         reference_owner = childdoc['reference_owner_s']
                     except :
-                        pass
+                        reference_owner = None
+                        
                     try:
                         effectendpoint = childdoc['effectendpoint_s']
                     except :
@@ -522,21 +529,22 @@ class StudyDocuments:
                         for condition in conditions[study_id]:
                             if condition == "type_s" or condition=="document_uuid_s" or condition=="id" or condition=="topcategory_s" or condition=="endpointcategory_s":
                                 continue
-                            row["x.conditions." + condition.replace("_s","")] = conditions[study_id][condition]
+                            
+                            row["x.conditions." + re.sub("_s$","",condition)] = conditions[study_id][condition]
                     except:
                         pass
                     try:
                         for prm in params[document_uuid]:
                             if prm == "type_s" or prm=="document_uuid_s" or prm=="id" or prm=="topcategory_s" or prm=="endpointcategory_s":
                                 continue
-                            row["x.params."+prm.replace("_s","")] = params[document_uuid][prm]
+                            row["x.params."+re.sub("_s$","",prm)] = params[document_uuid][prm]
                     except:
                         pass
 
                     try:
                         fields = self.settings["fields"]["conditions"]
                         for field in fields:
-                            key="x.conditions." + field.replace("_s", "")
+                            key="x.conditions." + re.sub("_s$","",field)
                             value = conditions[study_id][field]
                             if pd.isna(value):
                                 value=np.nan
@@ -547,7 +555,7 @@ class StudyDocuments:
                     try:
                         fields = self.settings["fields"]["params"]
                         for field in fields:
-                            key="x.params."+field.replace("_s", "")
+                            key="x.params." + re.sub("_s$","",field)
                             value = params[doc_uuid][field]
                             if pd.isna(value):
                                 value=np.nan
